@@ -71,6 +71,8 @@ private slots:
     void functionArguments();
     void namespaces();
     void useNamespace();
+    void useGroupedNamespace();
+    void useGroupedPartialNamespace();
     void useNamespaceFunctionConst();
     void lateStatic();
     void closures();
@@ -91,6 +93,11 @@ private slots:
     void returnTypeFunction();
     void defaultValue();
     void propertyType();
+    void functionParameterUnionType();
+    void functionReturnUnionType();
+    void closureParameterUnionType();
+    void closureReturnUnionType();
+    void propertyUnionType();
 };
 
 }
